@@ -26,12 +26,25 @@ from strawberry_resources.exporter import to_json
     default=False,
     help="Remove null values from the output to keep its size smaller",
 )
-def export(schema: str, app_dir: str, remove_nulls: bool):
+@click.option(
+    "--remove-nested-types-fields",
+    is_flag=True,
+    show_default=True,
+    default=False,
+    help="Remove nested types fields to keep the output size smaller",
+)
+def export(
+    schema: str,
+    app_dir: str,
+    remove_nulls: bool,
+    remove_nested_types_fields: bool,
+):
     schema_obj = load_schema(schema, app_dir)
     sys.stdout.write(
         to_json(
             schema_obj,
             remove_nulls=remove_nulls,
+            remove_nested_types_fields=remove_nested_types_fields,
             indent=2,
             ensure_ascii=False,
         ),
