@@ -19,6 +19,7 @@ from django.db.models.fields import NOT_PROVIDED
 from strawberry import UNSET
 from strawberry.field import StrawberryField
 from strawberry.scalars import JSON
+from strawberry.type import StrawberryOptional
 from strawberry_django.fields.types import (
     DjangoFileType,
     DjangoImageType,
@@ -78,7 +79,7 @@ def _get_model_field(
     model: Type[models.Model],
     field: str,
 ) -> Optional[Union[models.Field, models.ForeignObjectRel]]:
-    meta = model._meta  # noqa: SLF001
+    meta = model._meta
     for f in meta.get_fields():
         name = cast(str, resolve_model_field_name(f, is_input=False, is_filter=False))
         if name == field:
@@ -118,17 +119,24 @@ def get_field_options(
     )
 
     options: FieldOptions = {}
+    if (
+        relay is not None
+        and isinstance(resolved_type, type)
+        and issubclass(resolved_type, relay.GlobalID)
+    ):
+        options["kind"] = FieldKind.ID
 
-    if (dj_type := _get_django_type(origin)) is None:
-        return {}
-
-    f_type = field.type
-    model = dj_type.model
-    model_attr = getattr(model, field.name, None)
+    if (dj_type := _get_django_type(origin)) is not None:
+        model = dj_type.model
+        model_attr = getattr(model, field.name, None)
+    else:
+        model = None
+        model_attr = None
 
     # Try to populate options from the model property
     if (
         ModelProperty is not None
+        and model_attr is not None
         and isinstance(model_attr, ModelProperty)
         and (get_origin(annotation := model_attr.func.__annotations__.get("return")) is Annotated)
     ):
@@ -141,7 +149,7 @@ def get_field_options(
 
             options.update(opt.options)
 
-    dj_field = _get_model_field(model, field.name)
+    dj_field = _get_model_field(model, field.name) if model is not None else None
 
     if hasattr(resolved_type, "_type_definition"):
         field_obj_options: FieldObjectOptions = {}
@@ -152,7 +160,7 @@ def get_field_options(
             field_obj_options["obj_kind"] = FieldObjectKind.LIST_INPUT
 
         label = options.get("label")
-        if label is None:
+        if label is None and dj_field is not None:
             label = getattr(dj_field, "verbose_name", None)
         if label is not None:
             field_obj_options["label"] = label
@@ -160,17 +168,17 @@ def get_field_options(
         return field_obj_options
 
     if dj_field is None:
-        return {}
+        return options
 
     choices: Optional[List[FieldChoice]] = None
     default_value = v if (v := getattr(dj_field, "default", None)) is not NOT_PROVIDED else None
-    if isinstance(f_type, type) and issubclass(f_type, models.Choices):
+    if isinstance(resolved_type, type) and issubclass(resolved_type, models.Choices):
         if choices is None:
             choices = [
                 FieldChoice(label=lbl, value=cast(JSON, value))
-                for lbl, value in zip(f_type.labels, f_type.names)
+                for lbl, value in zip(resolved_type.labels, resolved_type.names)
             ]
-        default_value = f_type(default_value).name if default_value is not None else None
+        default_value = resolved_type(default_value).name if default_value is not None else None
     elif choices is None and (items := getattr(dj_field, "choices", None)):
         if isinstance(items, dict):
             items = items.items()
@@ -199,9 +207,9 @@ def get_field_options(
     if (help_text := getattr(dj_field, "help_Text", None) or None) is not None:
         options["help_text"] = help_text
 
-    if (order := dj_type.order) and order is not UNSET:
+    if dj_type and (order := dj_type.order) and order is not UNSET:
         options["orderable"] = field.name in {f.name for f in dataclasses.fields(cast(type, order))}
-    if (filters := dj_type.filters) and filters is not UNSET:
+    if dj_type and (filters := dj_type.filters) and filters is not UNSET:
         options["filterable"] = field.name in {
             f.name for f in dataclasses.fields(cast(type, filters))
         }
@@ -221,6 +229,7 @@ def get_field_options(
     elif isinstance(dj_field, models.CharField):
         options["kind"] = FieldKind.STRING
         options["validation"] = StringFieldValidation(
+            required=not isinstance(field.type, StrawberryOptional),
             min_length=0 if dj_field.blank else 1,
             max_length=dj_field.max_length,
         )
@@ -231,6 +240,7 @@ def get_field_options(
     elif isinstance(dj_field, models.DecimalField):
         options["kind"] = FieldKind.DECIMAL
         options["validation"] = DecimalFieldValidation(
+            required=not isinstance(field.type, StrawberryOptional),
             max_digits=dj_field.max_digits,
             decimal_places=dj_field.decimal_places,
         )
