@@ -96,7 +96,7 @@ def resolve_all(schema: Schema):
 
 
 def resolve_fields_for_type(type_: type, *, depth: int = 0):
-    type_def = cast(TypeDefinition, type_._type_definition)  # type: ignore  # noqa: SLF001
+    type_def = cast(TypeDefinition, type_._type_definition)  # type: ignore
     integrations = get_all()
 
     for field in type_def.fields:
@@ -124,6 +124,8 @@ def resolve_fields_for_type(type_: type, *, depth: int = 0):
             is_list = is_list or isinstance(f_type, StrawberryList)
             f_type = f_type.of_type
 
+        options["multiple"] = is_list
+
         if isinstance(f_type, LazyType):
             f_type = f_type.resolve_type()
         if isinstance(f_type, EnumDefinition):
@@ -198,7 +200,7 @@ def resolve_fields_for_type(type_: type, *, depth: int = 0):
 
             inner_type_def = cast(
                 TypeDefinition,
-                f_type._type_definition,  # type: ignore  # noqa: SLF001
+                f_type._type_definition,  # type: ignore
             )
 
             assert isinstance(f_type, type)
@@ -210,7 +212,12 @@ def resolve_fields_for_type(type_: type, *, depth: int = 0):
                     (True, True): FieldObjectKind.INPUT_LIST,
                     (False, True): FieldObjectKind.INPUT,
                 }
-                obj_kind = obj_kind_map[(is_list, getattr(inner_type_def, "is_input", False))]
+                obj_kind = obj_kind_map[
+                    (
+                        options.get("multiple", False),
+                        getattr(inner_type_def, "is_input", False),
+                    )
+                ]
 
             yield FieldObject(
                 name=cname,
